<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
    xmlns:tei="http://www.tei-c.org/ns/1.0" exclude-result-prefixes="tei">
    <xsl:output encoding="utf-8" method="xml" indent="no" omit-xml-declaration="yes"/>

    <xsl:key name="id" match="tei:*" use="@xml:id"/>

    <xsl:template match="tei:*[@corresp]">
       <xsl:if test="not(contains(@corresp,' '))">
           <xsl:message terminate="yes">
               <xsl:text>Bad @corresp </xsl:text>
               <xsl:value-of select="@corresp"/>
           </xsl:message>
       </xsl:if>
       <xsl:call-template name="para">
         <xsl:with-param name="corresp" select="substring-before(@corresp,' ')"/>
         <xsl:with-param name="id" select="@xml:id"/>
       </xsl:call-template>
        <xsl:call-template name="para">
          <xsl:with-param name="corresp" select="substring-after(@corresp,' ')"/>
        </xsl:call-template>
    </xsl:template>
    <xsl:template name="para">
        <xsl:param name="corresp"/>
        <xsl:param name="id"/>
        <xsl:if test="not(starts-with($corresp,'#'))">
            <xsl:message terminate="yes">
                <xsl:text>Bad @corresp </xsl:text>
                <xsl:value-of select="$corresp"/>
            </xsl:message>
        </xsl:if>
        <xsl:apply-templates mode="corresp" select="key('id',substring-after($corresp,'#'))">
          <xsl:with-param name="id" select="$id"/>
        </xsl:apply-templates>
    </xsl:template>
  
    <!-- discard lb in dipl so that better alignment with crit -->
    <xsl:template mode="corresp" match="tei:lb"/>
    <xsl:template mode="corresp" match="tei:*">
      <xsl:param name="id"/>
      <xsl:variable name="type">
        <xsl:choose>
          <xsl:when test="ancestor::tei:div[@type='dipl']">dipl</xsl:when>
          <xsl:when test="ancestor::tei:div[@type='crit']">crit</xsl:when>
          <xsl:otherwise>
            <xsl:message terminate="yes">Bad para ancestor!</xsl:message>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <xsl:if test="not($type='dipl' and self::tei:pb)">
        <xsl:copy>
          <xsl:apply-templates mode="corresp" select="@*"/>
          <xsl:if test="normalize-space($id)">
            <xsl:attribute name="xml:id">
              <xsl:value-of select="$id"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:if test="not(@type or 
                        name()='abbr' or name()='expan' or name()='sic' or name()='corr' or name()='add' or name()='del'
                        )">
            <xsl:attribute name="type">
              <xsl:value-of select="$type"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:apply-templates mode="corresp"/>
        </xsl:copy>
      </xsl:if>
    </xsl:template>
    <xsl:template mode="corresp" match="@*">
      <xsl:if test="not(name() = 'xml:id')">
        <xsl:copy/>
      </xsl:if>
    </xsl:template>
    <xsl:template mode="corresp" match="text()">
      <xsl:value-of select="."/>
    </xsl:template>

    <xsl:template match="tei:*">
        <xsl:copy>
            <xsl:apply-templates select="@*"/>
            <xsl:apply-templates select="*|comment()|text()"/>
        </xsl:copy>
    </xsl:template>
    <xsl:template match="@*">
        <xsl:copy/>
    </xsl:template>
</xsl:stylesheet>
